@@ -21,13 +21,7 @@ DRIVER_PREFERENCE = {
     "default": ["Chrome", "Firefox"],
 }
 
-CHROMEDRIVER_VERSIONS = {
-    "81": "81.0.4044.69",
-    "80": "80.0.3987.106",
-    "79": "79.0.3945.36",
-}
-
-CHROME_VERSION_PATTERN = r"(\d+)(\.\d+\.\d+.\d+)"
+CHROME_VERSION_PATTERN = r"(\d+\.\d+.\d+)(\.\d+)"
 CHROME_VERSION_COMMANDS = {
     "Windows": [
         [
@@ -51,7 +45,6 @@ CHROME_VERSION_COMMANDS = {
         ["google-chrome", "--version"],
     ],
     "Darwin": [
-        ["/Applications/Google Chrome.app/Contents/MacOS/Google Chrome", "--version"],
         ["/Applications/Google Chrome.app/Contents/MacOS/Google Chrome", "--version"],
         ["/Applications/Chromium.app/Contents/MacOS/Chromium", "--version"],
     ],
@@ -85,7 +78,7 @@ def executable(browser: str, download: bool = False) -> str:
         chrome_version = _chrome_version()
         driver_version = _chromedriver_version(driver_path)
         if chrome_version != driver_version:
-            _download_driver(factory, chrome_version)
+            _download_driver(factory)
     else:
         LOGGER.info("Driver download skipped, because it exists at '%s'", driver_path)
 
@@ -126,9 +119,10 @@ def _chrome_version() -> str:
     commands = CHROME_VERSION_COMMANDS.get(system)
 
     if not commands:
-        LOGGER.error("Unsupported system: %s", system)
+        LOGGER.warning("Unsupported system: %s", system)
+        return None
 
-    for cmd in CHROME_VERSION_COMMANDS:
+    for cmd in commands:
         output = _run_command(cmd)
         if not output:
             continue
@@ -137,8 +131,7 @@ def _chrome_version() -> str:
         if not version:
             continue
 
-        major = version.group(1)
-        return CHROMEDRIVER_VERSIONS.get(major)
+        return version.group(1)
 
     return None
 
@@ -152,8 +145,7 @@ def _chromedriver_version(path: Path) -> str:
     if not version:
         return None
 
-    major = version.group(1)
-    return CHROMEDRIVER_VERSIONS.get(major)
+    return version.group(1)
 
 
 def _download_driver(factory: Any, version: str = None) -> None:
@@ -188,7 +180,8 @@ def _set_executable_permissions(path: str) -> None:
 
 def _run_command(args: List[str]) -> str:
     try:
-        return subprocess.check_output(args, stderr=subprocess.STDOUT, shell=True)
-    except FileNotFoundError:
-        LOGGER.debug('Command "%s" not found', args[0])
+        output = subprocess.check_output(args)
+        return output.decode().strip()
+    except (FileNotFoundError, subprocess.CalledProcessError) as err:
+        LOGGER.debug("Command failed: %s", err)
         return None
